@@ -3,7 +3,7 @@ package WebService::MusicBrainz::Response;
 use strict;
 use XML::LibXML;
 
-our $VERSION = '0.92';
+our $VERSION = '0.94';
 
 =head1 NAME
 
@@ -698,7 +698,14 @@ sub _create_release_event_list {
        push @events, $event;
    }
 
-   $release_event_list->events( \@events );
+   # should use a date object here but cheating with cmp to reduce dependencies for now...
+   if(scalar(@events) > 1) {
+       my @sorted_events = sort { $a->date() cmp $b->date() } @events;
+
+       $release_event_list->events( \@sorted_events );
+   } else {
+       $release_event_list->events( \@events );
+   }
 
    return $release_event_list;
 }
